package com.huimv.manager.service.impl;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.huimv.manager.entity.BaseFarmInfoEntity;
import com.huimv.manager.entity.vo.DailySowVo;
import com.huimv.manager.entity.vo.DailyVo;
import com.huimv.manager.mapper.BaseFarmInfoDao;
import com.huimv.manager.mapper.DailyTabulateDataDao;
import com.huimv.manager.result.R;
import com.huimv.manager.result.RRException;
import jdk.nashorn.internal.ir.IfNode;
import net.bytebuddy.implementation.bytecode.Throw;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.manager.utils.PageUtils;
import com.huimv.manager.utils.Query;

import com.huimv.manager.entity.DailyTabulateDataEntity;
import com.huimv.manager.service.DailyTabulateDataService;

/**
 * 耳标每日汇总表
 *
 * @author yinhao
 * @version ${version}
 * @date 2021-07-24 16:29:33
 */
@Service("dailyTabulateDataService")
public class DailyTabulateDataServiceImpl extends ServiceImpl<DailyTabulateDataDao, DailyTabulateDataEntity> implements DailyTabulateDataService {
    @Autowired
    private BaseFarmInfoDao baseFarmInfoDao;

    @Override
    public PageUtils queryPage(Map<String, Object> params) {
       String farmCode =(String) params.get("farmCode");
       if (StringUtils.isBlank(farmCode)){
           throw new RRException("牧场未选择");
       }
       String startTime =(String) params.get("startTime");
       String endTime =(String) params.get("endTime");
       String minStockTotal =(String) params.get("minStockTotal");
       String maxStockTotal =(String) params.get("maxStockTotal");
       String minStockNew =(String) params.get("minStockNew");
       String maxStockNew =(String) params.get("maxStockNew");
       String minOfflineNo =(String) params.get("minOfflineNo");
       String maxOfflineNo =(String) params.get("maxOfflineNo");
       String minSowStock =(String) params.get("minSowStock");
       String maxSowStock =(String) params.get("maxSowStock");

        QueryWrapper<DailyTabulateDataEntity> wrapper = new QueryWrapper<>();
        wrapper.eq("farm_code",farmCode);

        wrapper.ge(StringUtils.isNotBlank(startTime),"statistic_date",startTime);
        wrapper.le(StringUtils.isNotBlank(startTime),"statistic_date",endTime);

        wrapper.ge(StringUtils.isNotBlank(minStockTotal),"stock_total",minStockTotal);
        wrapper.le(StringUtils.isNotBlank(maxStockTotal),"stock_total",maxStockTotal);

        wrapper.ge(StringUtils.isNotBlank(minStockNew),"stock_new",minStockNew);
        wrapper.le(StringUtils.isNotBlank(maxStockNew),"stock_new",maxStockNew);

        wrapper.ge(StringUtils.isNotBlank(minOfflineNo),"offline_no",minOfflineNo);
        wrapper.le(StringUtils.isNotBlank(maxOfflineNo),"offline_no",maxOfflineNo);

        wrapper.ge(StringUtils.isNotBlank(minOfflineNo),"sow_stock",minSowStock);
        wrapper.le(StringUtils.isNotBlank(maxOfflineNo),"sow_stock",maxSowStock);


        IPage<DailyTabulateDataEntity> page = this.page(
                new Query<DailyTabulateDataEntity>().getPage(params),
                wrapper
        );

        return new PageUtils(page);
    }

    @Override
    public DailyTabulateDataEntity listByFarm(Map<String, Object> params) {
        String date = (String) params.get("date");
        String farmCode = (String) params.get("farmCode");
        if (StringUtils.isBlank(farmCode)){
            throw new RRException("请选择牧场");
        }
        if (StringUtils.isBlank(date) ){
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
            date = simpleDateFormat.format(new Date());
        }
        QueryWrapper<DailyTabulateDataEntity> wrapper = new QueryWrapper<>();
        wrapper.eq("statistic_date",date);
        wrapper.eq("farm_code",farmCode);


        return   baseMapper.selectOne(wrapper);
    }

    @Override
    public List countAllChange(Map<String, Object> params) {
        List<DailyVo> list = new ArrayList<>();

        String farmCode = (String)params.get("farmCode");
        String startDate = (String)params.get("startDate");
        String endDate = (String)params.get("endDate");
        String type = (String)params.get("type");

        if (farmCode == null){
            throw new RRException("请选择牧场");
        }

        QueryWrapper<DailyTabulateDataEntity> wrapper = new QueryWrapper<>();
        wrapper.eq("farm_code",farmCode);
        wrapper.ge(StringUtils.isNotBlank(startDate),"statistic_date",startDate);
        wrapper.ge(StringUtils.isNotBlank(startDate),"statistic_date",endDate);
        wrapper.groupBy("ydate");
        wrapper.orderByDesc("statistic_date");

        if ("1".equals(type)){
            if (StringUtils.isBlank(startDate) || StringUtils.isBlank(endDate)){
                wrapper.last("limit 7");
            }
            list = baseMapper.selectDay(wrapper);
        }
        if ("2".equals(type)){
            if (StringUtils.isBlank(startDate) || StringUtils.isBlank(endDate)){
                wrapper.last("limit 6");
            }
            list = baseMapper.selectMonth(wrapper);
        }
        if ("3".equals(type)){
            if (StringUtils.isBlank(startDate) || StringUtils.isBlank(endDate)){
                wrapper.last("limit 5");
            }
            list = baseMapper.selectYear(wrapper);
        }

        return list;
    }

    @Override
    public List countAllsow(Map<String, Object> params) {
//        String type =(String)params.get("type");
        String countyCode = (String)params.get("countyCode");

        QueryWrapper<BaseFarmInfoEntity> wrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(countyCode)){
            wrapper.eq("county",countyCode).or().eq("city",countyCode);
        }

        List<String>  farmCodeList = new ArrayList();
        List<BaseFarmInfoEntity> baseFarmInfoEntities = baseFarmInfoDao.selectList(wrapper);
        for (BaseFarmInfoEntity baseFarmInfoEntity : baseFarmInfoEntities) {
            farmCodeList.add( baseFarmInfoEntity.getFarmCode());
        }
        wrapper.in("farm_code",farmCodeList);
        wrapper.eq("statistic_date", DateUtil.beginOfDay(new Date()));
        DailySowVo dailySowVo = baseMapper.counSowAll(wrapper);

        return null;
    }
}